@@ -34,7 +34,7 @@ sub _set_keys {
 	my ($self, $hash) = @_;
 
 	for my $k (@KEYS) {
-		next if !exists $hash->{ $k };
+		carp "no '$k' specified in config" and next if !exists $hash->{ $k };
 		$self->{ $k } = $hash->{ $k };
 	}
 }
